/* Placed in public domain by Dmitry Mityugov, 2003 */

#include <nwcalls.h>
#include <nwclxcon.h>
#include <nwsm.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int main( int argc, char* argv[]) {
	char const* server_name;
	char const* user_name;
	char const* password;
	char const* load_command;
	NWCCODE ccode;
	NWRCODE rcode;
	NWCONN_HANDLE conn_handle;
	nuint32 load_ret_code = 0;
	if ( argc != 5) {
		puts( "\rUsage: RLoad <servername> <username> <password> <load_command>");
		return EXIT_FAILURE;
	}
	ccode = NWCallsInit( NULL, NULL);
	if ( ccode != 0) {
		printf( "\rRLoad: NWCallsInit failed, ccode = %x\n", ccode);
		return EXIT_FAILURE;
	}
	server_name = strupr( argv[ 1]);
	user_name = strupr( argv[ 2]);
	password = strupr( argv[ 3]);
	load_command = argv[ 4];
	rcode = NWCCOpenConnByName( 0,
		server_name,
		NWCC_NAME_FORMAT_BIND,
		NWCC_OPEN_LICENSED,
		NWCC_TRAN_TYPE_WILD,
		&conn_handle);
	if ( rcode != 0) {
		printf( "\rRLoad: NWCCOpenConnByName failed, rcode = %x\n", rcode);
		NWCallsTerm( NULL);
		return EXIT_FAILURE;
	}
	ccode = NWLoginToFileServer( conn_handle, user_name, OT_USER, password);
	if ( ccode != 0) {
		printf( "\rRLoad: NWLoginToFileServer failed, ccode = %x\n", ccode);
		NWCCCloseConn( conn_handle);
		NWCallsTerm( NULL);
		return EXIT_FAILURE;
	}
	ccode = NWSMLoadNLM2( conn_handle, load_command, &load_ret_code);
	if ( ccode != 0) {
		printf( "\rRLoad: NWSMLoadNLM2 failed, ccode = %x, load_ret_code = %d\n", ccode, load_ret_code);
		NWCCCloseConn( conn_handle);
		NWCallsTerm( NULL);
		return EXIT_FAILURE;
	}
	NWCCCloseConn( conn_handle);
	NWCallsTerm( NULL);
	return EXIT_SUCCESS;
}
